@@ -77,7 +77,7 @@ void RecentFilesMenu::addDirectory(const QString& dir)
  */
 void RecentFilesMenu::saveEntries(ISettings* config)
 {
-  config->beginGroup(QLatin1String("RecentFiles"));
+  config->beginGroup(QLatin1String("RecentFiles"), true);
   config->setValue(QLatin1String("Files"), QVariant(m_files));
   config->endGroup();
 }
@@ -89,7 +89,7 @@ void RecentFilesMenu::saveEntries(ISettings* config)
  */
 void RecentFilesMenu::loadEntries(ISettings* config)
 {
-  config->beginGroup(QLatin1String("RecentFiles"));
+  config->beginGroup(QLatin1String("RecentFiles"), true);
   m_files = config->value(QLatin1String("Files"), m_files).toStringList();
   config->endGroup();
 
