@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 5 Mar 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,11 +24,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef FINDREPLACECONFIG_H
-#define FINDREPLACECONFIG_H
+#pragma once
 
 #include <QStringList>
-#include "config.h"
 #include "generalconfig.h"
 #include "tagsearcher.h"
 #include "kid3api.h"
@@ -41,9 +39,11 @@ class BatchImportProfile;
 class KID3_CORE_EXPORT FindReplaceConfig : public StoredConfig<FindReplaceConfig> {
   Q_OBJECT
   /** search parameters */
-  Q_PROPERTY(QVariantList parameterList READ parameterList WRITE setParameterList NOTIFY parameterListChanged)
+  Q_PROPERTY(QVariantList parameterList READ parameterList
+             WRITE setParameterList NOTIFY parameterListChanged)
   /** window geometry */
-  Q_PROPERTY(QByteArray windowGeometry READ windowGeometry WRITE setWindowGeometry NOTIFY windowGeometryChanged)
+  Q_PROPERTY(QByteArray windowGeometry READ windowGeometry
+             WRITE setWindowGeometry NOTIFY windowGeometryChanged)
 
 public:
   /**
@@ -54,21 +54,21 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FindReplaceConfig();
+  virtual ~FindReplaceConfig() override = default;
 
   /**
    * Persist configuration.
    *
    * @param config configuration
    */
-  virtual void writeToConfig(ISettings* config) const;
+  virtual void writeToConfig(ISettings* config) const override;
 
   /**
    * Read persisted configuration.
    *
    * @param config configuration
    */
-  virtual void readFromConfig(ISettings* config);
+  virtual void readFromConfig(ISettings* config) override;
 
   /**
    * Get search parameters.
@@ -126,5 +126,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif
