@@ -40,6 +40,9 @@ class KID3_CORE_EXPORT MainWindowConfig : public StoredConfig<MainWindowConfig>
   /** mainwindow state */
   Q_PROPERTY(QByteArray windowState READ windowState WRITE setWindowState
              NOTIFY windowStateChanged)
+  /** application language */
+  Q_PROPERTY(QString language READ language WRITE setLanguage
+             NOTIFY languageChanged)
   /** custom application font family */
   Q_PROPERTY(QString fontFamily READ fontFamily WRITE setFontFamily
              NOTIFY fontFamilyChanged)
@@ -59,6 +62,9 @@ class KID3_CORE_EXPORT MainWindowConfig : public StoredConfig<MainWindowConfig>
   /** Don't use the native file dialog if true */
   Q_PROPERTY(bool dontUseNativeDialogs READ dontUseNativeDialogs
              WRITE setDontUseNativeDialogs NOTIFY dontUseNativeDialogsChanged)
+  /** Qt Quick style and theme, empty if not used */
+  Q_PROPERTY(QString qtQuickStyle READ qtQuickStyle WRITE setQtQuickStyle
+             NOTIFY qtQuickStyleChanged)
 
 public:
   /**
@@ -97,6 +103,12 @@ public:
   /** Set mainwindow state. */
   void setWindowState(const QByteArray& windowState);
 
+  /** Get application language. */
+  QString language() const { return m_language; }
+
+  /** Set application language. */
+  void setLanguage(const QString& language);
+
   /** Get custom application font family. */
   QString fontFamily() const { return m_fontFamily; }
 
@@ -139,6 +151,22 @@ public:
   /** Set if native file dialogs are used. */
   void setDontUseNativeDialogs(bool dontUseNativeDialogs);
 
+  /** Get Qt Quick style, empty if not used. */
+  QString qtQuickStyle() const { return m_qtQuickStyle; }
+
+  /** Set Qt Quick style. */
+  void setQtQuickStyle(const QString& qtQuickStyle);
+
+  /**
+   * String list of available Qt Quick styles.
+   */
+  Q_INVOKABLE static QStringList getQtQuickStyleNames();
+
+  /**
+   * List of available languages.
+   */
+  Q_INVOKABLE static QStringList availableLanguages();
+
 signals:
   /** Emitted when @a geometry changed. */
   void geometryChanged(const QByteArray& geometry);
@@ -146,6 +174,9 @@ signals:
   /** Emitted when @a windowState changed. */
   void windowStateChanged(const QByteArray& windowState);
 
+  /** Emitted when @a language changed. */
+  void languageChanged(const QString& language);
+
   /** Emitted when @a fontFamily changed. */
   void fontFamilyChanged(const QString& fontFamily);
 
@@ -167,14 +198,19 @@ signals:
   /** Emitted when @a dontUseNativeDialogs changed. */
   void dontUseNativeDialogsChanged(bool dontUseNativeDialogs);
 
+  /** Emitted when @a qtQuickStyle changed. */
+  void qtQuickStyleChanged(const QString& qtQuickStyle);
+
 private:
   friend MainWindowConfig& StoredConfig<MainWindowConfig>::instance();
 
   QByteArray m_geometry;
   QByteArray m_windowState;
+  QString m_language;
   QString m_fontFamily;
   int m_fontSize;
   QString m_style;
+  QString m_qtQuickStyle;
   bool m_useFont;
   bool m_hideToolBar;
   bool m_hideStatusBar;
