@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Mar 2011
  *
- * Copyright (C) 2005-2011  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,15 +24,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef COMMANDSTABLEMODEL_H
-#define COMMANDSTABLEMODEL_H
+#pragma once
 
 #include <QAbstractTableModel>
-#include <QHeaderView>
 #include <QList>
 #include "useractionsconfig.h"
 #include "kid3api.h"
 
+enum class ModelSectionResizeMode : int;
+
 /**
  * Context menu commands configuration table model.
  */
@@ -43,19 +43,19 @@ public:
    * Constructor.
    * @param parent parent widget
    */
-  explicit CommandsTableModel(QObject* parent = 0);
+  explicit CommandsTableModel(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~CommandsTableModel();
+  virtual ~CommandsTableModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const;
+  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -64,7 +64,7 @@ public:
    * @return data for role
    */
   virtual QVariant data(const QModelIndex& index,
-                        int role=Qt::DisplayRole) const;
+                        int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for a given role.
@@ -74,7 +74,7 @@ public:
    * @return true if successful
    */
   virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role=Qt::EditRole);
+                       int role = Qt::EditRole) override;
 
   /**
    * Get data for header section.
@@ -84,7 +84,7 @@ public:
    * @return header data for role
    */
   virtual QVariant headerData(int section, Qt::Orientation orientation,
-                              int role=Qt::DisplayRole) const;
+                              int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for header section.
@@ -92,7 +92,7 @@ public:
    * @return false
    */
   virtual bool setHeaderData(int, Qt::Orientation, const QVariant&,
-                             int=Qt::EditRole) { return false; }
+                             int = Qt::EditRole) override { return false; }
 
   /**
    * Get number of rows.
@@ -100,7 +100,7 @@ public:
    * @return number of rows,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int rowCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get number of columns.
@@ -108,7 +108,7 @@ public:
    * @return number of columns,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int columnCount(const QModelIndex& parent=QModelIndex()) const;
+  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Insert rows.
@@ -119,7 +119,7 @@ public:
    * @return true if successful
    */
   virtual bool insertRows(int row, int count,
-                          const QModelIndex& parent=QModelIndex());
+                          const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Remove rows.
@@ -129,13 +129,13 @@ public:
    * @return true if successful
    */
   virtual bool removeRows(int row, int count,
-                          const QModelIndex& parent=QModelIndex());
+                          const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Get the resize modes to be used for the columns.
    * @return list of resize modes for the columns
    */
-  QList<QHeaderView::ResizeMode> getHorizontalResizeModes() const;
+  QList<ModelSectionResizeMode> getHorizontalResizeModes() const;
 
   /**
    * Set the model from the command list.
@@ -152,5 +152,3 @@ public:
 private:
   QList<UserActionsConfig::MenuCommand> m_cmdList;
 };
-
-#endif // COMMANDSTABLEMODEL_H
