@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 11-Jan-2009
  *
- * Copyright (C) 2009  Urs Fleisch
+ * Copyright (C) 2009-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,10 +24,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef BROWSECOVERARTDIALOG_H
-#define BROWSECOVERARTDIALOG_H
+#pragma once
 
 #include <QDialog>
+#include <QScopedPointer>
 #include "frame.h"
 
 class QTextEdit;
@@ -36,25 +36,26 @@ class ExternalProcess;
 class ConfigTable;
 class ConfigTableModel;
 class FormatListEdit;
+class Kid3Application;
 
 /**
  * Browse cover art dialog.
  */
 class BrowseCoverArtDialog : public QDialog {
-Q_OBJECT
-
+  Q_OBJECT
 public:
   /**
    * Constructor.
    *
+   * @param app application context
    * @param parent parent widget
    */
-  explicit BrowseCoverArtDialog(QWidget* parent);
+  explicit BrowseCoverArtDialog(Kid3Application* app, QWidget* parent);
 
   /**
    * Destructor.
    */
-  virtual ~BrowseCoverArtDialog();
+  virtual ~BrowseCoverArtDialog() override;
 
   /**
    * Read the local settings from the configuration.
@@ -72,7 +73,7 @@ public slots:
   /**
    * Hide modal dialog, start browse command.
    */
-  virtual void accept();
+  virtual void accept() override;
 
 private slots:
   /**
@@ -113,8 +114,8 @@ private:
 
   /** Track data */
   FrameCollection m_frames;
+  /** Application context */
+  Kid3Application* m_app;
   /** Process for browser command */
-  ExternalProcess* m_process;
+  QScopedPointer<ExternalProcess> m_process;
 };
-
-#endif
